==> nunit_2.2.8.orig.tar.gz: nunit-2.2.8.orig/src/GuiRunner/tests/UserSettingsTests.cs <==
#region Copyright (c) 2003, James W. Newkirk, Michael C. Two, Alexei A. Vorontsov, Charlie Poole, Philip A. Craig
/************************************************************************************
'
' Copyright  2002-2003 James W. Newkirk, Michael C. Two, Alexei A. Vorontsov, Charlie Poole
' Copyright  2000-2002 Philip A. Craig
'
' This software is provided 'as-is', without any express or implied warranty. In no 
' event will the authors be held liable for any damages arising from the use of this 
' software.
' 
' Permission is granted to anyone to use this software for any purpose, including 
' commercial applications, and to alter it and redistribute it freely, subject to the 
' following restrictions:
'
' 1. The origin of this software must not be misrepresented; you must not claim that 
' you wrote the original software. If you use this software in a product, an 
' acknowledgment (see the following) in the product documentation is required.
'
' Portions Copyright  2002-2003 James W. Newkirk, Michael C. Two, Alexei A. Vorontsov, Charlie Poole
' or Copyright  2000-2002 Philip A. Craig
'
' 2. Altered source versions must be plainly marked as such, and must not be 
' misrepresented as being the original software.
'
' 3. This notice may not be removed or altered from any source distribution.
'
'***********************************************************************************/
#endregion

using System;
using System.Drawing;
using NUnit.Framework;
using NUnit.Util;
using Microsoft.Win32;

namespace NUnit.Gui.Tests
{
	/// <summary>
	/// Summary description for UserSettingsTests.
	/// </summary>
	[TestFixture]
	public class UserSettingsTests
	{
		[SetUp]
		public void Init()
		{
			NUnitRegistry.TestMode = true;
			NUnitRegistry.ClearTestKeys();
		}

		[TearDown]
		public void Cleanup()
		{
			NUnitRegistry.TestMode = false;
		}
		
		[Test]
		public void GetStorageImpl()
		{
			Assert.AreEqual( @"HKEY_CURRENT_USER\Software\Nascent Software\Nunit-Test",
				UserSettings.GetStorageImpl().StorageName );
		}

		[Test]
		public void GetChildStorageImpl()
		{
			Assert.AreEqual( "MySettings", 
				UserSettings.GetStorageImpl( "MySettings" ).StorageName );
		}

		[Test]
		public void OptionSettings()
		{
			Assert.IsNotNull( new UserSettings().Options );
		}

		[Test]
		public void FormSettings()
		{
			Assert.IsNotNull( new UserSettings().Form );
		}

		[Test]
		public void RecentProjects()
		{
			Assert.IsNotNull( new UserSettings().RecentProjects );
		}
	}
}

==> nunit_2.4.7+dfsg.orig.tar.gz: nunit-2.4.7/src/GuiRunner/tests/UserSettingsTests.cs <==
#region Copyright (c) 2003, James W. Newkirk, Michael C. Two, Alexei A. Vorontsov, Charlie Poole, Philip A. Craig
/************************************************************************************
'
' Copyright  2002-2003 James W. Newkirk, Michael C. Two, Alexei A. Vorontsov, Charlie Poole
' Copyright  2000-2002 Philip A. Craig
'
' This software is provided 'as-is', without any express or implied warranty. In no 
' event will the authors be held liable for any damages arising from the use of this 
' software.
' 
' Permission is granted to anyone to use this software for any purpose, including 
' commercial applications, and to alter it and redistribute it freely, subject to the 
' following restrictions:
'
' 1. The origin of this software must not be misrepresented; you must not claim that 
' you wrote the original software. If you use this software in a product, an 
' acknowledgment (see the following) in the product documentation is required.
'
' Portions Copyright  2002-2003 James W. Newkirk, Michael C. Two, Alexei A. Vorontsov, Charlie Poole
' or Copyright  2000-2002 Philip A. Craig
'
' 2. Altered source versions must be plainly marked as such, and must not be 
' misrepresented as being the original software.
'
' 3. This notice may not be removed or altered from any source distribution.
'
'***********************************************************************************/
#endregion

using System;
using System.Drawing;
using NUnit.Framework;
using NUnit.Util;
using Microsoft.Win32;

namespace NUnit.Gui.Tests
{
	/// <summary>
	/// Summary description for UserSettingsTests.
	/// </summary>
	[TestFixture]
	public class UserSettingsTests
	{
		UserSettings settings;

		[SetUp]
		public void Init()
		{
			settings = new UserSettings( new MemorySettingsStorage() );
		}

		[TearDown]
		public void Cleanup()
		{
			settings.Dispose();
		}
		
		[Test]
		public void OptionSettings()
		{
			Assert.IsInstanceOfType( typeof( MemorySettingsStorage ), settings.Options.Storage );
		}

		[Test]
		public void FormSettings()
		{
			Assert.IsInstanceOfType( typeof( MemorySettingsStorage ), settings.Form.Storage );
		}

		[Test]
		public void RecentProjects()
		{
			Assert.IsInstanceOfType( typeof( MemorySettingsStorage ), settings.RecentProjects.Storage );
		}
	}
}
